@@ -1,3 +1,5 @@
+from testtools.matchers import (
+    AfterPreprocessing, Raises, MatchesAll, IsInstance)
 from twisted.web import http
 from twisted.web.http_headers import Headers
 from twisted.web.test.requesthelper import DummyRequest
@@ -18,3 +20,14 @@ class InMemoryRequest(DummyRequest):
     def redirect(self, url):
         self.setResponseCode(http.FOUND)
         self.setHeader(b'location', url)
+
+
+def MatchesException(exc_type, matcher):
+    """
+    Match an exception type and a user-provided matcher against the exception
+    instance.
+    """
+    return Raises(
+        AfterPreprocessing(
+            lambda x: x[1],
+            MatchesAll(IsInstance(exc_type), matcher)))
